summaryrefslogtreecommitdiffstats
path: root/tools
diff options
context:
space:
mode:
Diffstat (limited to 'tools')
-rw-r--r--tools/assistant/tabbedbrowser.ui.h2
-rw-r--r--tools/designer/designer.pro2
-rw-r--r--tools/designer/designer/connectiondialog.ui.h2
-rw-r--r--tools/designer/designer/designer_de.ts2
-rw-r--r--tools/designer/designer/designer_fr.ts2
-rw-r--r--tools/designer/designer/formfile.cpp2
-rw-r--r--tools/designer/designer/formsettings.ui2
-rw-r--r--tools/designer/designer/formwindow.cpp2
-rw-r--r--tools/designer/designer/listeditor.ui.h2
-rw-r--r--tools/designer/designer/resource.cpp2
-rw-r--r--tools/designer/designer/richtextfontdialog.ui.h2
-rw-r--r--tools/designer/examples/addressbook/addressbook.ui.h2
-rw-r--r--tools/designer/examples/addressbook/addressdetails.ui.h2
-rw-r--r--tools/designer/examples/addressbook/search.ui.h2
-rw-r--r--tools/designer/examples/colortool/colornameform.ui.h2
-rw-r--r--tools/designer/examples/colortool/findform.ui.h2
-rw-r--r--tools/designer/examples/colortool/mainform.ui.h2
-rw-r--r--tools/designer/examples/colortool/optionsform.ui.h2
-rw-r--r--tools/designer/examples/credit/creditformbase.cpp2
-rw-r--r--tools/designer/examples/credit/creditformbase.h2
-rw-r--r--tools/designer/examples/metric/metric.ui.h2
-rw-r--r--tools/designer/plugins/cppeditor/mainfilesettings.ui.h2
-rw-r--r--tools/designer/plugins/cppeditor/projectsettings.ui.h2
-rw-r--r--tools/designer/plugins/kdevdlg/main.cpp2
-rw-r--r--tools/designer/plugins/rc/main.cpp2
-rw-r--r--tools/designer/shared/domtool.cpp2
-rw-r--r--tools/designer/shared/ui2uib.cpp2
-rw-r--r--tools/designer/shared/uib.h2
-rw-r--r--tools/designer/shared/widgetdatabase.cpp18
-rw-r--r--tools/designer/tquic/embed.cpp (renamed from tools/designer/uic/embed.cpp)6
-rw-r--r--tools/designer/tquic/form.cpp (renamed from tools/designer/uic/form.cpp)14
-rw-r--r--tools/designer/tquic/main.cpp (renamed from tools/designer/uic/main.cpp)20
-rw-r--r--tools/designer/tquic/object.cpp (renamed from tools/designer/uic/object.cpp)14
-rw-r--r--tools/designer/tquic/subclassing.cpp (renamed from tools/designer/uic/subclassing.cpp)10
-rw-r--r--tools/designer/tquic/tquic.cpp (renamed from tools/designer/uic/uic.cpp)92
-rw-r--r--tools/designer/tquic/tquic.h (renamed from tools/designer/uic/uic.h)4
-rw-r--r--tools/designer/tquic/tquic.pro (renamed from tools/designer/uic/uic.pro)6
37 files changed, 120 insertions, 120 deletions
diff --git a/tools/assistant/tabbedbrowser.ui.h b/tools/assistant/tabbedbrowser.ui.h
index 425840d3..68513fb9 100644
--- a/tools/assistant/tabbedbrowser.ui.h
+++ b/tools/assistant/tabbedbrowser.ui.h
@@ -1,5 +1,5 @@
/****************************************************************************
-** ui.h extension file, included from the uic-generated form implementation.
+** ui.h extension file, included from the tquic-generated form implementation.
**
** If you wish to add, delete or rename functions or slots use
** TQt Designer which will update this file, preserving your code. Create an
diff --git a/tools/designer/designer.pro b/tools/designer/designer.pro
index bbe68ada..21646f89 100644
--- a/tools/designer/designer.pro
+++ b/tools/designer/designer.pro
@@ -2,7 +2,7 @@ TEMPLATE = subdirs
CONFIG += ordered
-SUBDIRS = uic \
+SUBDIRS = tquic \
uilib \
designer \
app \
diff --git a/tools/designer/designer/connectiondialog.ui.h b/tools/designer/designer/connectiondialog.ui.h
index 010a5c19..6c4951b6 100644
--- a/tools/designer/designer/connectiondialog.ui.h
+++ b/tools/designer/designer/connectiondialog.ui.h
@@ -1,5 +1,5 @@
/****************************************************************************
-** ui.h extension file, included from the uic-generated form implementation.
+** ui.h extension file, included from the tquic-generated form implementation.
**
** If you wish to add, delete or rename slots use TQt Designer which will
** update this file, preserving your code. Create an init() slot in place of
diff --git a/tools/designer/designer/designer_de.ts b/tools/designer/designer/designer_de.ts
index 0461b304..f92fe096 100644
--- a/tools/designer/designer/designer_de.ts
+++ b/tools/designer/designer/designer_de.ts
@@ -1353,7 +1353,7 @@ filename &apos;%1&apos;. Please choose a new filename.</source>
<translation type="unfinished"></translation>
</message>
<message encoding="UTF-8">
- <source>&lt;b&gt;Enter the name of the class that will be created.&lt;/b&gt;&lt;p&gt;&lt;em&gt;classname.h&lt;/em&gt; and &lt;em&gt;classname.cpp&lt;/em&gt; will be generated as C++-output when it is compiled with the uic.&lt;/p&gt;</source>
+ <source>&lt;b&gt;Enter the name of the class that will be created.&lt;/b&gt;&lt;p&gt;&lt;em&gt;classname.h&lt;/em&gt; and &lt;em&gt;classname.cpp&lt;/em&gt; will be generated as C++-output when it is compiled with the tquic.&lt;/p&gt;</source>
<translation type="unfinished"></translation>
</message>
<message encoding="UTF-8">
diff --git a/tools/designer/designer/designer_fr.ts b/tools/designer/designer/designer_fr.ts
index c31eba6b..a185365c 100644
--- a/tools/designer/designer/designer_fr.ts
+++ b/tools/designer/designer/designer_fr.ts
@@ -1351,7 +1351,7 @@ filename &apos;%1&apos;. Please choose a new filename.</source>
<translation type="unfinished"></translation>
</message>
<message encoding="UTF-8">
- <source>&lt;b&gt;Enter the name of the class that will be created.&lt;/b&gt;&lt;p&gt;&lt;em&gt;classname.h&lt;/em&gt; and &lt;em&gt;classname.cpp&lt;/em&gt; will be generated as C++-output when it is compiled with the uic.&lt;/p&gt;</source>
+ <source>&lt;b&gt;Enter the name of the class that will be created.&lt;/b&gt;&lt;p&gt;&lt;em&gt;classname.h&lt;/em&gt; and &lt;em&gt;classname.cpp&lt;/em&gt; will be generated as C++-output when it is compiled with the tquic.&lt;/p&gt;</source>
<translation type="unfinished"></translation>
</message>
<message encoding="UTF-8">
diff --git a/tools/designer/designer/formfile.cpp b/tools/designer/designer/formfile.cpp
index 322dcff1..2870f57c 100644
--- a/tools/designer/designer/formfile.cpp
+++ b/tools/designer/designer/formfile.cpp
@@ -509,7 +509,7 @@ TQString FormFile::codeExtension() const
TQString FormFile::codeComment() const
{
return TQString( "/****************************************************************************\n"
- "** ui.h extension file, included from the uic-generated form implementation.\n"
+ "** ui.h extension file, included from the tquic-generated form implementation.\n"
"**\n"
"** If you want to add, delete, or rename functions or slots, use\n"
"** TQt Designer to update this file, preserving your code.\n"
diff --git a/tools/designer/designer/formsettings.ui b/tools/designer/designer/formsettings.ui
index 7b605aa6..535a53f1 100644
--- a/tools/designer/designer/formsettings.ui
+++ b/tools/designer/designer/formsettings.ui
@@ -173,7 +173,7 @@
<string>Change class name</string>
</property>
<property name="whatsThis" stdset="0">
- <string>&lt;b&gt;Enter the name of the class that will be created.&lt;/b&gt;&lt;p&gt;&lt;em&gt;classname.h&lt;/em&gt; and &lt;em&gt;classname.cpp&lt;/em&gt; will be generated as C++ output when it is compiled by uic.&lt;/p&gt;</string>
+ <string>&lt;b&gt;Enter the name of the class that will be created.&lt;/b&gt;&lt;p&gt;&lt;em&gt;classname.h&lt;/em&gt; and &lt;em&gt;classname.cpp&lt;/em&gt; will be generated as C++ output when it is compiled by tquic.&lt;/p&gt;</string>
</property>
</widget>
<widget class="TQLabel" row="3" column="0">
diff --git a/tools/designer/designer/formwindow.cpp b/tools/designer/designer/formwindow.cpp
index a5451bdd..8b7514f7 100644
--- a/tools/designer/designer/formwindow.cpp
+++ b/tools/designer/designer/formwindow.cpp
@@ -1834,7 +1834,7 @@ bool FormWindow::checkCustomWidgets()
"but are not known to TQt Designer:\n" ).arg( name() );
for ( TQStringList::Iterator sit = missingCustomWidgets.begin(); sit != missingCustomWidgets.end(); ++sit )
txt += " " + *sit + "\n";
- txt += "If you save this form and generate code for it using uic, \n"
+ txt += "If you save this form and generate code for it using tquic, \n"
"the generated code will not compile.\n"
"Do you want to save this form now?";
if ( TQMessageBox::information( mainWindow(), tr( "Save Form" ), txt ) == 1 )
diff --git a/tools/designer/designer/listeditor.ui.h b/tools/designer/designer/listeditor.ui.h
index a7ee2796..e28e9055 100644
--- a/tools/designer/designer/listeditor.ui.h
+++ b/tools/designer/designer/listeditor.ui.h
@@ -1,5 +1,5 @@
/****************************************************************************
-** ui.h extension file, included from the uic-generated form implementation.
+** ui.h extension file, included from the tquic-generated form implementation.
**
** If you wish to add, delete or rename slots use TQt Designer which will
** update this file, preserving your code. Create an init() slot in place of
diff --git a/tools/designer/designer/resource.cpp b/tools/designer/designer/resource.cpp
index d2f913b0..e65493c5 100644
--- a/tools/designer/designer/resource.cpp
+++ b/tools/designer/designer/resource.cpp
@@ -2219,7 +2219,7 @@ TQWidget *Resource::createSpacer( const TQDomElement &e, TQWidget *parent, TQLay
}
/*!
- Attention: this function has to be in sync with Uic::setObjectProperty(). If you change one, change both.
+ Attention: this function has to be in sync with TQUic::setObjectProperty(). If you change one, change both.
*/
void Resource::setObjectProperty( TQObject* obj, const TQString &prop, const TQDomElement &e )
{
diff --git a/tools/designer/designer/richtextfontdialog.ui.h b/tools/designer/designer/richtextfontdialog.ui.h
index 27a11a21..68d0bd71 100644
--- a/tools/designer/designer/richtextfontdialog.ui.h
+++ b/tools/designer/designer/richtextfontdialog.ui.h
@@ -1,5 +1,5 @@
/****************************************************************************
-** ui.h extension file, included from the uic-generated form implementation.
+** ui.h extension file, included from the tquic-generated form implementation.
**
** If you wish to add, delete or rename slots use TQt Designer which will
** update this file, preserving your code. Create an init() slot in place of
diff --git a/tools/designer/examples/addressbook/addressbook.ui.h b/tools/designer/examples/addressbook/addressbook.ui.h
index 6964e40b..35cf1e73 100644
--- a/tools/designer/examples/addressbook/addressbook.ui.h
+++ b/tools/designer/examples/addressbook/addressbook.ui.h
@@ -1,5 +1,5 @@
/****************************************************************************
-** ui.h extension file, included from the uic-generated form implementation.
+** ui.h extension file, included from the tquic-generated form implementation.
**
** If you wish to add, delete or rename slots use TQt Designer which will
** update this file, preserving your code. Create an init() slot in place of
diff --git a/tools/designer/examples/addressbook/addressdetails.ui.h b/tools/designer/examples/addressbook/addressdetails.ui.h
index b4e73924..bf14ecde 100644
--- a/tools/designer/examples/addressbook/addressdetails.ui.h
+++ b/tools/designer/examples/addressbook/addressdetails.ui.h
@@ -1,5 +1,5 @@
/****************************************************************************
-** ui.h extension file, included from the uic-generated form implementation.
+** ui.h extension file, included from the tquic-generated form implementation.
**
** If you wish to add, delete or rename slots use TQt Designer which will
** update this file, preserving your code. Create an init() slot in place of
diff --git a/tools/designer/examples/addressbook/search.ui.h b/tools/designer/examples/addressbook/search.ui.h
index 67715379..8c08f0dd 100644
--- a/tools/designer/examples/addressbook/search.ui.h
+++ b/tools/designer/examples/addressbook/search.ui.h
@@ -1,5 +1,5 @@
/****************************************************************************
-** ui.h extension file, included from the uic-generated form implementation.
+** ui.h extension file, included from the tquic-generated form implementation.
**
** If you wish to add, delete or rename slots use TQt Designer which will
** update this file, preserving your code. Create an init() slot in place of
diff --git a/tools/designer/examples/colortool/colornameform.ui.h b/tools/designer/examples/colortool/colornameform.ui.h
index 70d7f62f..6d4f37bf 100644
--- a/tools/designer/examples/colortool/colornameform.ui.h
+++ b/tools/designer/examples/colortool/colornameform.ui.h
@@ -1,5 +1,5 @@
/****************************************************************************
-** ui.h extension file, included from the uic-generated form implementation.
+** ui.h extension file, included from the tquic-generated form implementation.
**
** If you wish to add, delete or rename functions use TQt Designer which will
** update this file, preserving your code. Create an init() function in place
diff --git a/tools/designer/examples/colortool/findform.ui.h b/tools/designer/examples/colortool/findform.ui.h
index 1f3e993b..3a6a9e30 100644
--- a/tools/designer/examples/colortool/findform.ui.h
+++ b/tools/designer/examples/colortool/findform.ui.h
@@ -1,5 +1,5 @@
/****************************************************************************
-** ui.h extension file, included from the uic-generated form implementation.
+** ui.h extension file, included from the tquic-generated form implementation.
**
** If you wish to add, delete or rename functions use TQt Designer which will
** update this file, preserving your code. Create an init() function in place
diff --git a/tools/designer/examples/colortool/mainform.ui.h b/tools/designer/examples/colortool/mainform.ui.h
index 7a0f8a8d..0ec5059d 100644
--- a/tools/designer/examples/colortool/mainform.ui.h
+++ b/tools/designer/examples/colortool/mainform.ui.h
@@ -1,5 +1,5 @@
/****************************************************************************
-** ui.h extension file, included from the uic-generated form implementation.
+** ui.h extension file, included from the tquic-generated form implementation.
**
** If you wish to add, delete or rename functions use TQt Designer which will
** update this file, preserving your code. Create an init() function in place
diff --git a/tools/designer/examples/colortool/optionsform.ui.h b/tools/designer/examples/colortool/optionsform.ui.h
index e43b8f3f..e126094a 100644
--- a/tools/designer/examples/colortool/optionsform.ui.h
+++ b/tools/designer/examples/colortool/optionsform.ui.h
@@ -1,5 +1,5 @@
/****************************************************************************
-** ui.h extension file, included from the uic-generated form implementation.
+** ui.h extension file, included from the tquic-generated form implementation.
**
** If you wish to add, delete or rename functions use TQt Designer which will
** update this file, preserving your code. Create an init() function in place
diff --git a/tools/designer/examples/credit/creditformbase.cpp b/tools/designer/examples/credit/creditformbase.cpp
index 73b060db..dd1428b6 100644
--- a/tools/designer/examples/credit/creditformbase.cpp
+++ b/tools/designer/examples/credit/creditformbase.cpp
@@ -2,7 +2,7 @@
** Form implementation generated from reading ui file 'creditformbase.ui'
**
** Created: Fri Aug 10 09:48:16 2001
-** by: The User Interface Compiler (uic)
+** by: The User Interface Compiler (tquic)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/
diff --git a/tools/designer/examples/credit/creditformbase.h b/tools/designer/examples/credit/creditformbase.h
index 6c0ecc80..8422a123 100644
--- a/tools/designer/examples/credit/creditformbase.h
+++ b/tools/designer/examples/credit/creditformbase.h
@@ -2,7 +2,7 @@
** Form interface generated from reading ui file 'creditformbase.ui'
**
** Created: Fri Aug 10 09:48:10 2001
-** by: The User Interface Compiler (uic)
+** by: The User Interface Compiler (tquic)
**
** WARNING! All changes made in this file will be lost!
****************************************************************************/
diff --git a/tools/designer/examples/metric/metric.ui.h b/tools/designer/examples/metric/metric.ui.h
index 465a044c..d2706be5 100644
--- a/tools/designer/examples/metric/metric.ui.h
+++ b/tools/designer/examples/metric/metric.ui.h
@@ -1,5 +1,5 @@
/****************************************************************************
-** ui.h extension file, included from the uic-generated form implementation.
+** ui.h extension file, included from the tquic-generated form implementation.
**
** If you wish to add, delete or rename functions respectively slots use
** TQt Designer which will update this file, preserving your code. Create an
diff --git a/tools/designer/plugins/cppeditor/mainfilesettings.ui.h b/tools/designer/plugins/cppeditor/mainfilesettings.ui.h
index 7dd3906c..8ac48ad0 100644
--- a/tools/designer/plugins/cppeditor/mainfilesettings.ui.h
+++ b/tools/designer/plugins/cppeditor/mainfilesettings.ui.h
@@ -1,5 +1,5 @@
/****************************************************************************
-** ui.h extension file, included from the uic-generated form implementation.
+** ui.h extension file, included from the tquic-generated form implementation.
**
** If you wish to add, delete or rename slots use TQt Designer which will
** update this file, preserving your code. Create an init() slot in place of
diff --git a/tools/designer/plugins/cppeditor/projectsettings.ui.h b/tools/designer/plugins/cppeditor/projectsettings.ui.h
index 32e770c9..7ec8e021 100644
--- a/tools/designer/plugins/cppeditor/projectsettings.ui.h
+++ b/tools/designer/plugins/cppeditor/projectsettings.ui.h
@@ -1,5 +1,5 @@
/****************************************************************************
-** ui.h extension file, included from the uic-generated form implementation.
+** ui.h extension file, included from the tquic-generated form implementation.
**
** Add custom slot implementations here. Use a slot init() for
** initialization code called during construction, and a slot destroy()
diff --git a/tools/designer/plugins/kdevdlg/main.cpp b/tools/designer/plugins/kdevdlg/main.cpp
index 57d293a2..af5c08c9 100644
--- a/tools/designer/plugins/kdevdlg/main.cpp
+++ b/tools/designer/plugins/kdevdlg/main.cpp
@@ -89,7 +89,7 @@ TQStringList KDevDlgFilter::import( const TQString &, const TQString& filename )
{
TQFile file( filename );
if ( !file.open( IO_ReadOnly ) )
- tqWarning( "uic: Could not open file '%s' ", filename.latin1() );
+ tqWarning( "tquic: Could not open file '%s' ", filename.latin1() );
TQTextStream in;
in.setDevice( &file );
diff --git a/tools/designer/plugins/rc/main.cpp b/tools/designer/plugins/rc/main.cpp
index 9825ea64..c43a1726 100644
--- a/tools/designer/plugins/rc/main.cpp
+++ b/tools/designer/plugins/rc/main.cpp
@@ -87,7 +87,7 @@ TQStringList RCFilter::import( const TQString &, const TQString& filename )
{
TQFile file( filename );
if ( !file.open( IO_ReadOnly ) )
- tqWarning( "uic: Could not open file '%s' ", filename.latin1() );
+ tqWarning( "tquic: Could not open file '%s' ", filename.latin1() );
TQTextStream in;
in.setDevice( &file );
diff --git a/tools/designer/shared/domtool.cpp b/tools/designer/shared/domtool.cpp
index 46f999f8..498dec7f 100644
--- a/tools/designer/shared/domtool.cpp
+++ b/tools/designer/shared/domtool.cpp
@@ -47,7 +47,7 @@
\brief Tools for the dom
A collection of static functions used by Resource (part of the
- designer) and Uic.
+ designer) and TQUic.
*/
diff --git a/tools/designer/shared/ui2uib.cpp b/tools/designer/shared/ui2uib.cpp
index 4eddea7e..3e31dda0 100644
--- a/tools/designer/shared/ui2uib.cpp
+++ b/tools/designer/shared/ui2uib.cpp
@@ -126,7 +126,7 @@
specified.
6. Some of the information stored in a .ui file is useful only
- by uic, not to TQLayoutFactory. That information is, for now,
+ by tquic, not to TQLayoutFactory. That information is, for now,
not taken along in the .uib file. Likewise, needless
TQLayoutWidget objects are not taken along.
diff --git a/tools/designer/shared/uib.h b/tools/designer/shared/uib.h
index 5307595c..8ee070ee 100644
--- a/tools/designer/shared/uib.h
+++ b/tools/designer/shared/uib.h
@@ -89,7 +89,7 @@ private:
};
/*
- uic uses insertCString(), insertString(), and block();
+ tquic uses insertCString(), insertString(), and block();
TQWidgetFactory uses readBlock(), asCString(), and asString(). By
implementing these functions inline, we ensure that the binaries
don't contain needless code.
diff --git a/tools/designer/shared/widgetdatabase.cpp b/tools/designer/shared/widgetdatabase.cpp
index 4fd0d79b..e74139ef 100644
--- a/tools/designer/shared/widgetdatabase.cpp
+++ b/tools/designer/shared/widgetdatabase.cpp
@@ -109,7 +109,7 @@ WidgetDatabase::WidgetDatabase()
void WidgetDatabase::setupDataBase( int id )
{
was_in_setup = TRUE;
-#ifndef UIC
+#ifndef TQUIC
Q_UNUSED( id )
if ( dbcount )
return;
@@ -240,7 +240,7 @@ void WidgetDatabase::setupDataBase( int id )
append( r );
-#if !defined(TQT_NO_ICONVIEW) || defined(UIC)
+#if !defined(TQT_NO_ICONVIEW) || defined(TQUIC)
r = new WidgetDatabaseRecord;
r->iconSet = "designer_iconview.png";
r->name = "TQIconView";
@@ -572,7 +572,7 @@ void WidgetDatabase::setupDataBase( int id )
append( r );
#endif
-#ifndef UIC
+#ifndef TQUIC
setupPlugins();
#endif
}
@@ -592,7 +592,7 @@ void WidgetDatabase::setupPlugins()
if ( !iface )
continue;
-#ifndef UIC
+#ifndef TQUIC
TQIconSet icon = iface->iconSet( *it );
if ( !icon.pixmap().isNull() )
r->icon = new TQIconSet( icon );
@@ -642,7 +642,7 @@ TQIconSet WidgetDatabase::iconSet( int id )
WidgetDatabaseRecord *r = at( id );
if ( !r )
return TQIconSet();
-#if !defined(UIC) && !defined(RESOURCE)
+#if !defined(TQUIC) && !defined(RESOURCE)
if ( !r->icon ) {
if ( r->iconSet.isEmpty() )
return TQIconSet();
@@ -792,7 +792,7 @@ int WidgetDatabase::idFromClassName( const TQString &name )
return *i;
if ( name == "FormWindow" )
return idFromClassName( "TQLayoutWidget" );
-#ifdef UIC
+#ifdef TQUIC
setupDataBase( -2 );
i = className2Id->find( name );
if ( i )
@@ -932,7 +932,7 @@ void WidgetDatabase::loadWhatsThis( const TQString &docPath )
// ### TQt 3.1: make these publically accessible via TQWidgetDatabase API
-#if defined(UIC)
+#if defined(TQUIC)
bool dbnounload = FALSE;
TQStringList *dbpaths = 0;
#else
@@ -944,13 +944,13 @@ TQPluginManager<WidgetInterface> *widgetManager()
{
if ( !widgetPluginManager ) {
TQString pluginDir = "/designer";
-#if !defined(UIC)
+#if !defined(TQUIC)
if ( qwf_plugin_dir )
pluginDir = *qwf_plugin_dir;
#endif
widgetPluginManager = new TQPluginManager<WidgetInterface>( IID_Widget, TQApplication::libraryPaths(), pluginDir );
cleanup_manager.add( &widgetPluginManager );
-#if defined(UIC)
+#if defined(TQUIC)
if ( dbnounload )
widgetPluginManager->setAutoUnload( FALSE );
if ( dbpaths ) {
diff --git a/tools/designer/uic/embed.cpp b/tools/designer/tquic/embed.cpp
index d16abc6c..42202300 100644
--- a/tools/designer/uic/embed.cpp
+++ b/tools/designer/tquic/embed.cpp
@@ -31,7 +31,7 @@
**
**********************************************************************/
-#include "uic.h"
+#include "tquic.h"
#include <tqfile.h>
#include <tqimage.h>
#include <tqstringlist.h>
@@ -117,7 +117,7 @@ static void embedData( TQTextStream& out, const TQRgb* input, int n )
out << dec; // back to decimal mode
}
-void Uic::embed( TQTextStream& out, const char* project, const TQStringList& images )
+void TQUic::embed( TQTextStream& out, const char* project, const TQStringList& images )
{
TQString cProject = convertToCIdentifier( project );
@@ -148,7 +148,7 @@ void Uic::embed( TQTextStream& out, const char* project, const TQStringList& ima
for ( it = images.begin(); it != images.end(); ++it ) {
TQImage img;
if ( !img.load( *it ) ) {
- fprintf( stderr, "uic: cannot load image file %s\n", (*it).latin1() );
+ fprintf( stderr, "tquic: cannot load image file %s\n", (*it).latin1() );
continue;
}
EmbedImage *e = new EmbedImage;
diff --git a/tools/designer/uic/main.cpp b/tools/designer/tquic/main.cpp
index c754d73e..636ffd43 100644
--- a/tools/designer/uic/main.cpp
+++ b/tools/designer/tquic/main.cpp
@@ -31,7 +31,7 @@
**
**********************************************************************/
-#include "uic.h"
+#include "tquic.h"
#include "domtool.h"
#if defined(UIB)
#include "ui2uib.h"
@@ -197,7 +197,7 @@ int main( int argc, char * argv[] )
if ( argc < 2 || error || (!fileName && !imagecollection ) ) {
fprintf( stderr, "TQt user interface compiler.\n" );
if ( error )
- fprintf( stderr, "uic: %s\n", error );
+ fprintf( stderr, "tquic: %s\n", error );
fprintf( stderr, "Usage: %s [options] [mode] <uifile>\n\n"
"Generate declaration:\n"
@@ -230,7 +230,7 @@ int main( int argc, char * argv[] )
"\t-nounload Don't unload plugins after processing\n"
"\t-tr func Use func() instead of tr() for i18n\n"
"\t-L path Additional plugin search path\n"
- "\t-version Display version of uic\n"
+ "\t-version Display version of tquic\n"
"\t-help Display this information\n"
, argv[0], argv[0], argv[0], argv[0], argv[0], argv[0], argv[0]
#if defined(UIB)
@@ -265,7 +265,7 @@ int main( int argc, char * argv[] )
if ( !outputFile.isEmpty() ) {
fileOut.setName( outputFile );
if (!fileOut.open( IO_WriteOnly ) ) {
- tqWarning( "uic: Could not open output file '%s'", outputFile.data() );
+ tqWarning( "tquic: Could not open output file '%s'", outputFile.data() );
return 1;
}
} else {
@@ -275,7 +275,7 @@ int main( int argc, char * argv[] )
if ( imagecollection ) {
out.setEncoding( TQTextStream::Latin1 );
- Uic::embed( out, projectName, images );
+ TQUic::embed( out, projectName, images );
return 0;
}
@@ -283,7 +283,7 @@ int main( int argc, char * argv[] )
TQFile file( fileName );
if ( !file.open( IO_ReadOnly ) ) {
- tqWarning( "uic: Could not open file '%s'", fileName );
+ tqWarning( "tquic: Could not open file '%s'", fileName );
return 1;
}
@@ -291,13 +291,13 @@ int main( int argc, char * argv[] )
TQString errMsg;
int errLine;
if ( !doc.setContent( &file, &errMsg, &errLine ) ) {
- tqWarning( TQString("uic: Failed to parse %s: ") + errMsg + TQString (" in line %d"), fileName, errLine );
+ tqWarning( TQString("tquic: Failed to parse %s: ") + errMsg + TQString (" in line %d"), fileName, errLine );
return 1;
}
TQDomElement e = doc.firstChild().toElement();
if ( e.hasAttribute("version") && e.attribute("version").toDouble() > 3.3 ) {
- tqWarning( TQString("uic: File generated with too recent version of TQt Designer (%s vs. %s)"),
+ tqWarning( TQString("tquic: File generated with too recent version of TQt Designer (%s vs. %s)"),
e.attribute("version").latin1(), TQT_VERSION_STR );
return 1;
}
@@ -343,14 +343,14 @@ int main( int argc, char * argv[] )
out << "#include \"" << headerFile << "\"" << endl << endl;
}
- Uic( fileName, outputFile, out, doc, !impl, subcl, trmacro, className, nofwd );
+ TQUic( fileName, outputFile, out, doc, !impl, subcl, trmacro, className, nofwd );
if ( !protector.isEmpty() ) {
out << endl;
out << "#endif // " << protector << endl;
}
if ( fileOut.status() != IO_Ok ) {
- tqWarning( "uic: Error writing to file" );
+ tqWarning( "tquic: Error writing to file" );
if ( !outputFile.isEmpty() )
remove( outputFile );
}
diff --git a/tools/designer/uic/object.cpp b/tools/designer/tquic/object.cpp
index cd3cfbe8..0ef19843 100644
--- a/tools/designer/uic/object.cpp
+++ b/tools/designer/tquic/object.cpp
@@ -31,7 +31,7 @@
**
**********************************************************************/
-#include "uic.h"
+#include "tquic.h"
#include "parser.h"
#include "domtool.h"
#include <tqregexp.h>
@@ -49,7 +49,7 @@
\sa createObjectImpl()
*/
-void Uic::createObjectDecl( const TQDomElement& e )
+void TQUic::createObjectDecl( const TQDomElement& e )
{
if ( e.tagName() == "vbox" ) {
out << " TQVBoxLayout* " << registerObject(getLayoutName(e) ) << ";" << endl;
@@ -90,7 +90,7 @@ void Uic::createObjectDecl( const TQDomElement& e )
static bool createdCentralWidget = FALSE;
-TQString Uic::createObjectImpl( const TQDomElement &e, const TQString& parentClass, const TQString& par, const TQString& layout )
+TQString TQUic::createObjectImpl( const TQDomElement &e, const TQString& parentClass, const TQString& par, const TQString& layout )
{
TQString parent( par );
if ( parent == "this" && isMainWindow ) {
@@ -351,7 +351,7 @@ TQString Uic::createObjectImpl( const TQDomElement &e, const TQString& parentCla
\sa createObjectDecl()
*/
-void Uic::createSpacerDecl( const TQDomElement &e )
+void TQUic::createSpacerDecl( const TQDomElement &e )
{
for ( TQDomElement n = e.firstChild().toElement();
!n.isNull(); n = n.nextSibling().toElement() )
@@ -369,7 +369,7 @@ void Uic::createSpacerDecl( const TQDomElement &e )
application font or palette change handlers in createFormImpl().
*/
-void Uic::createExclusiveProperty( const TQDomElement & e, const TQString& exclusiveProp )
+void TQUic::createExclusiveProperty( const TQDomElement & e, const TQString& exclusiveProp )
{
TQDomElement n;
TQString objClass = getClassName( e );
@@ -402,7 +402,7 @@ void Uic::createExclusiveProperty( const TQDomElement & e, const TQString& exclu
Resource::saveProperty() and DomTool::elementToVariant. If you
change one, change all.
*/
-TQString Uic::setObjectProperty( const TQString& objClass, const TQString& obj, const TQString &prop, const TQDomElement &e, bool stdset )
+TQString TQUic::setObjectProperty( const TQString& objClass, const TQString& obj, const TQString &prop, const TQDomElement &e, bool stdset )
{
TQString v;
if ( e.tagName() == "rect" ) {
@@ -721,7 +721,7 @@ TQString Uic::setObjectProperty( const TQString& objClass, const TQString& obj,
/*! Extracts a named object property from \a e.
*/
-TQDomElement Uic::getObjectProperty( const TQDomElement& e, const TQString& name )
+TQDomElement TQUic::getObjectProperty( const TQDomElement& e, const TQString& name )
{
TQDomElement n;
for ( n = e.firstChild().toElement();
diff --git a/tools/designer/uic/subclassing.cpp b/tools/designer/tquic/subclassing.cpp
index dd07cf20..2ceed658 100644
--- a/tools/designer/uic/subclassing.cpp
+++ b/tools/designer/tquic/subclassing.cpp
@@ -31,7 +31,7 @@
**
**********************************************************************/
-#include "uic.h"
+#include "tquic.h"
#include "parser.h"
#include "widgetdatabase.h"
#include "domtool.h"
@@ -50,7 +50,7 @@
\sa createSubImpl()
*/
-void Uic::createSubDecl( const TQDomElement &e, const TQString& subClass )
+void TQUic::createSubDecl( const TQDomElement &e, const TQString& subClass )
{
TQDomElement n;
TQDomNodeList nl;
@@ -177,7 +177,7 @@ void Uic::createSubDecl( const TQDomElement &e, const TQString& subClass )
out << "};" << endl;
}
-void Uic::writeFunctionsSubDecl( const TQStringList &fuLst, const TQStringList &typLst, const TQStringList &specLst )
+void TQUic::writeFunctionsSubDecl( const TQStringList &fuLst, const TQStringList &typLst, const TQStringList &specLst )
{
TQValueListConstIterator<TQString> it, it2, it3;
for ( it = fuLst.begin(), it2 = typLst.begin(), it3 = specLst.begin();
@@ -198,7 +198,7 @@ void Uic::writeFunctionsSubDecl( const TQStringList &fuLst, const TQStringList &
\sa createSubDecl()
*/
-void Uic::createSubImpl( const TQDomElement &e, const TQString& subClass )
+void TQUic::createSubImpl( const TQDomElement &e, const TQString& subClass )
{
TQDomElement n;
TQDomNodeList nl;
@@ -329,7 +329,7 @@ void Uic::createSubImpl( const TQDomElement &e, const TQString& subClass )
writeFunctionsSubImpl( privateSlots, privateSlotTypes, privateSlotSpecifier, subClass, "private slot" );
}
-void Uic::writeFunctionsSubImpl( const TQStringList &fuLst, const TQStringList &typLst, const TQStringList &specLst,
+void TQUic::writeFunctionsSubImpl( const TQStringList &fuLst, const TQStringList &typLst, const TQStringList &specLst,
const TQString &subClass, const TQString &descr )
{
TQValueListConstIterator<TQString> it, it2, it3;
diff --git a/tools/designer/uic/uic.cpp b/tools/designer/tquic/tquic.cpp
index bcd67029..b39ba4a4 100644
--- a/tools/designer/uic/uic.cpp
+++ b/tools/designer/tquic/tquic.cpp
@@ -31,7 +31,7 @@
**
**********************************************************************/
-#include "uic.h"
+#include "tquic.h"
#include "parser.h"
#include "widgetdatabase.h"
#include "domtool.h"
@@ -44,9 +44,9 @@
#include <stdio.h>
#include <stdlib.h>
-bool Uic::isMainWindow = FALSE;
+bool TQUic::isMainWindow = FALSE;
-TQString Uic::getComment( const TQDomNode& n )
+TQString TQUic::getComment( const TQDomNode& n )
{
TQDomNode child = n.firstChild();
while ( !child.isNull() ) {
@@ -57,22 +57,22 @@ TQString Uic::getComment( const TQDomNode& n )
return TQString::null;
}
-TQString Uic::mkBool( bool b )
+TQString TQUic::mkBool( bool b )
{
return b? "TRUE" : "FALSE";
}
-TQString Uic::mkBool( const TQString& s )
+TQString TQUic::mkBool( const TQString& s )
{
return mkBool( s == "true" || s == "1" );
}
-bool Uic::toBool( const TQString& s )
+bool TQUic::toBool( const TQString& s )
{
return s == "true" || s.toInt() != 0;
}
-TQString Uic::fixString( const TQString &str, bool encode )
+TQString TQUic::fixString( const TQString &str, bool encode )
{
TQString s;
if ( !encode ) {
@@ -98,7 +98,7 @@ TQString Uic::fixString( const TQString &str, bool encode )
return "\"" + s + "\"";
}
-TQString Uic::trcall( const TQString& sourceText, const TQString& comment )
+TQString TQUic::trcall( const TQString& sourceText, const TQString& comment )
{
if ( sourceText.isEmpty() && comment.isEmpty() )
return "TQString::null";
@@ -124,7 +124,7 @@ TQString Uic::trcall( const TQString& sourceText, const TQString& comment )
}
}
-TQString Uic::mkStdSet( const TQString& prop )
+TQString TQUic::mkStdSet( const TQString& prop )
{
return TQString( "set" ) + prop[0].upper() + prop.mid(1);
}
@@ -132,12 +132,12 @@ TQString Uic::mkStdSet( const TQString& prop )
/*!
- \class Uic uic.h
+ \class TQUic tquic.h
\brief User Interface Compiler
- The class Uic encapsulates the user interface compiler (uic).
+ The class TQUic encapsulates the user interface compiler (tquic).
*/
-Uic::Uic( const TQString &fn, const char *outputFn, TQTextStream &outStream,
+TQUic::TQUic( const TQString &fn, const char *outputFn, TQTextStream &outStream,
TQDomDocument doc, bool decl, bool subcl, const TQString &trm,
const TQString& subClass, bool omitForwardDecls )
: out( outStream ), trout( &languageChangeBody ),
@@ -215,7 +215,7 @@ Uic::Uic( const TQString &fn, const char *outputFn, TQTextStream &outStream,
/*! Extracts a pixmap loader function from \a e
*/
-TQString Uic::getPixmapLoaderFunction( const TQDomElement& e )
+TQString TQUic::getPixmapLoaderFunction( const TQDomElement& e )
{
TQDomElement n;
for ( n = e.firstChild().toElement(); !n.isNull(); n = n.nextSibling().toElement() ) {
@@ -228,7 +228,7 @@ TQString Uic::getPixmapLoaderFunction( const TQDomElement& e )
/*! Extracts the forms class name from \a e
*/
-TQString Uic::getFormClassName( const TQDomElement& e )
+TQString TQUic::getFormClassName( const TQDomElement& e )
{
TQDomElement n;
TQString cn;
@@ -246,7 +246,7 @@ TQString Uic::getFormClassName( const TQDomElement& e )
/*! Extracts a class name from \a e.
*/
-TQString Uic::getClassName( const TQDomElement& e )
+TQString TQUic::getClassName( const TQDomElement& e )
{
TQString s = e.attribute( "class" );
if ( s.isEmpty() && e.tagName() == "toolbar" )
@@ -259,7 +259,7 @@ TQString Uic::getClassName( const TQDomElement& e )
/*! Returns TRUE if database framework code is generated, else FALSE.
*/
-bool Uic::isFrameworkCodeGenerated( const TQDomElement& e )
+bool TQUic::isFrameworkCodeGenerated( const TQDomElement& e )
{
TQDomElement n = getObjectProperty( e, "frameworkCode" );
if ( n.attribute("name") == "frameworkCode" &&
@@ -271,7 +271,7 @@ bool Uic::isFrameworkCodeGenerated( const TQDomElement& e )
/*! Extracts an object name from \a e. It's stored in the 'name'
property.
*/
-TQString Uic::getObjectName( const TQDomElement& e )
+TQString TQUic::getObjectName( const TQDomElement& e )
{
TQDomElement n = getObjectProperty( e, "name" );
if ( n.firstChild().toElement().tagName() == "cstring" )
@@ -282,7 +282,7 @@ TQString Uic::getObjectName( const TQDomElement& e )
/*! Extracts an layout name from \a e. It's stored in the 'name'
property of the preceeding sibling (the first child of a TQLayoutWidget).
*/
-TQString Uic::getLayoutName( const TQDomElement& e )
+TQString TQUic::getLayoutName( const TQDomElement& e )
{
TQDomElement p = e.parentNode().toElement();
TQString name;
@@ -299,7 +299,7 @@ TQString Uic::getLayoutName( const TQDomElement& e )
}
-TQString Uic::getDatabaseInfo( const TQDomElement& e, const TQString& tag )
+TQString TQUic::getDatabaseInfo( const TQDomElement& e, const TQString& tag )
{
TQDomElement n;
TQDomElement n1;
@@ -327,7 +327,7 @@ TQString Uic::getDatabaseInfo( const TQDomElement& e, const TQString& tag )
}
-void Uic::registerLayouts( const TQDomElement &e )
+void TQUic::registerLayouts( const TQDomElement &e )
{
if ( layouts.contains(e.tagName())) {
createObjectDecl(e);
@@ -345,7 +345,7 @@ void Uic::registerLayouts( const TQDomElement &e )
/*!
Returns include file for class \a className or a null string.
*/
-TQString Uic::getInclude( const TQString& className )
+TQString TQUic::getInclude( const TQString& className )
{
int wid = WidgetDatabase::idFromClassName( className );
if ( wid != -1 )
@@ -354,7 +354,7 @@ TQString Uic::getInclude( const TQString& className )
}
-void Uic::createActionDecl( const TQDomElement& e )
+void TQUic::createActionDecl( const TQDomElement& e )
{
TQString objClass = e.tagName() == "action" ? "TQAction" : "TQActionGroup";
TQString objName = getObjectName( e );
@@ -369,13 +369,13 @@ void Uic::createActionDecl( const TQDomElement& e )
}
}
-void Uic::createToolbarDecl( const TQDomElement &e )
+void TQUic::createToolbarDecl( const TQDomElement &e )
{
if ( e.tagName() == "toolbar" )
out << " " << "TQToolBar *" << getObjectName( e ) << ";" << endl;
}
-void Uic::createMenuBarDecl( const TQDomElement &e )
+void TQUic::createMenuBarDecl( const TQDomElement &e )
{
if ( e.tagName() == "item" ) {
out << " " << "TQPopupMenu *" << e.attribute( "name" ) << ";" << endl;
@@ -383,7 +383,7 @@ void Uic::createMenuBarDecl( const TQDomElement &e )
}
}
-void Uic::createPopupMenuDecl( const TQDomElement &e )
+void TQUic::createPopupMenuDecl( const TQDomElement &e )
{
for ( TQDomElement n = e.firstChild().toElement(); !n.isNull(); n = n.nextSibling().toElement() ) {
if ( n.tagName() == "action" || n.tagName() == "actiongroup" ) {
@@ -397,7 +397,7 @@ void Uic::createPopupMenuDecl( const TQDomElement &e )
}
}
-void Uic::createActionImpl( const TQDomElement &n, const TQString &parent )
+void TQUic::createActionImpl( const TQDomElement &n, const TQString &parent )
{
for ( TQDomElement ae = n; !ae.isNull(); ae = ae.nextSibling().toElement() ) {
TQString objName = registerObject( getObjectName( ae ) );
@@ -470,7 +470,7 @@ TQString get_dock( const TQString &d )
return "";
}
-void Uic::createToolbarImpl( const TQDomElement &n, const TQString &parentClass, const TQString &parent )
+void TQUic::createToolbarImpl( const TQDomElement &n, const TQString &parentClass, const TQString &parent )
{
TQDomNodeList nl = n.elementsByTagName( "toolbar" );
for ( int i = 0; i < (int) nl.length(); i++ ) {
@@ -498,7 +498,7 @@ void Uic::createToolbarImpl( const TQDomElement &n, const TQString &parentClass,
}
}
-void Uic::createMenuBarImpl( const TQDomElement &n, const TQString &parentClass, const TQString &parent )
+void TQUic::createMenuBarImpl( const TQDomElement &n, const TQString &parentClass, const TQString &parent )
{
TQString objName = getObjectName( n );
out << indent << objName << " = new TQMenuBar( this, \"" << objName << "\" );" << endl;
@@ -525,7 +525,7 @@ void Uic::createMenuBarImpl( const TQDomElement &n, const TQString &parentClass,
}
}
-void Uic::createPopupMenuImpl( const TQDomElement &e, const TQString &parentClass, const TQString &parent )
+void TQUic::createPopupMenuImpl( const TQDomElement &e, const TQString &parentClass, const TQString &parent )
{
int i = 0;
for ( TQDomElement n = e.firstChild().toElement(); !n.isNull(); n = n.nextSibling().toElement() ) {
@@ -555,7 +555,7 @@ void Uic::createPopupMenuImpl( const TQDomElement &e, const TQString &parentClas
Creates implementation of an listbox item tag.
*/
-TQString Uic::createListBoxItemImpl( const TQDomElement &e, const TQString &parent,
+TQString TQUic::createListBoxItemImpl( const TQDomElement &e, const TQString &parent,
TQString *value )
{
TQDomElement n = e.firstChild().toElement();
@@ -594,7 +594,7 @@ TQString Uic::createListBoxItemImpl( const TQDomElement &e, const TQString &pare
Creates implementation of an iconview item tag.
*/
-TQString Uic::createIconViewItemImpl( const TQDomElement &e, const TQString &parent )
+TQString TQUic::createIconViewItemImpl( const TQDomElement &e, const TQString &parent )
{
TQDomElement n = e.firstChild().toElement();
TQString txt;
@@ -628,7 +628,7 @@ TQString Uic::createIconViewItemImpl( const TQDomElement &e, const TQString &par
Creates implementation of an listview item tag.
*/
-TQString Uic::createListViewItemImpl( const TQDomElement &e, const TQString &parent,
+TQString TQUic::createListViewItemImpl( const TQDomElement &e, const TQString &parent,
const TQString &parentItem )
{
TQString s;
@@ -693,7 +693,7 @@ TQString Uic::createListViewItemImpl( const TQDomElement &e, const TQString &par
Creates implementation of an listview column tag.
*/
-TQString Uic::createListViewColumnImpl( const TQDomElement &e, const TQString &parent,
+TQString TQUic::createListViewColumnImpl( const TQDomElement &e, const TQString &parent,
TQString *value )
{
TQDomElement n = e.firstChild().toElement();
@@ -736,7 +736,7 @@ TQString Uic::createListViewColumnImpl( const TQDomElement &e, const TQString &p
return s;
}
-TQString Uic::createTableRowColumnImpl( const TQDomElement &e, const TQString &parent,
+TQString TQUic::createTableRowColumnImpl( const TQDomElement &e, const TQString &parent,
TQString *value )
{
TQString objClass = getClassName( e.parentNode().toElement() );
@@ -805,7 +805,7 @@ TQString Uic::createTableRowColumnImpl( const TQDomElement &e, const TQString &p
/*!
Creates the implementation of a layout tag. Called from createObjectImpl().
*/
-TQString Uic::createLayoutImpl( const TQDomElement &e, const TQString& parentClass, const TQString& parent, const TQString& layout )
+TQString TQUic::createLayoutImpl( const TQDomElement &e, const TQString& parentClass, const TQString& parent, const TQString& layout )
{
TQDomElement n;
TQString objClass, objName;
@@ -902,7 +902,7 @@ TQString Uic::createLayoutImpl( const TQDomElement &e, const TQString& parentCla
-TQString Uic::createSpacerImpl( const TQDomElement &e, const TQString& /*parentClass*/, const TQString& /*parent*/, const TQString& /*layout*/)
+TQString TQUic::createSpacerImpl( const TQDomElement &e, const TQString& /*parentClass*/, const TQString& /*parent*/, const TQString& /*layout*/)
{
TQDomElement n;
TQString objClass, objName;
@@ -941,7 +941,7 @@ static const char* const ColorRole[] = {
/*!
Creates a colorgroup with name \a name from the color group \a cg
*/
-void Uic::createColorGroupImpl( const TQString& name, const TQDomElement& e )
+void TQUic::createColorGroupImpl( const TQString& name, const TQDomElement& e )
{
TQColorGroup cg;
int r = -1;
@@ -977,7 +977,7 @@ void Uic::createColorGroupImpl( const TQString& name, const TQDomElement& e )
Auxiliary function to load a color group. The colorgroup must not
contain pixmaps.
*/
-TQColorGroup Uic::loadColorGroup( const TQDomElement &e )
+TQColorGroup TQUic::loadColorGroup( const TQDomElement &e )
{
TQColorGroup cg;
int r = -1;
@@ -997,7 +997,7 @@ TQColorGroup Uic::loadColorGroup( const TQDomElement &e )
the database \a connection and \a table.
*/
-bool Uic::isWidgetInTable( const TQDomElement& e, const TQString& connection, const TQString& table )
+bool TQUic::isWidgetInTable( const TQDomElement& e, const TQString& connection, const TQString& table )
{
TQString conn = getDatabaseInfo( e, "connection" );
TQString tab = getDatabaseInfo( e, "table" );
@@ -1010,7 +1010,7 @@ bool Uic::isWidgetInTable( const TQDomElement& e, const TQString& connection, co
Registers all database connections, cursors and forms.
*/
-void Uic::registerDatabases( const TQDomElement& e )
+void TQUic::registerDatabases( const TQDomElement& e )
{
TQDomElement n;
TQDomNodeList nl;
@@ -1040,7 +1040,7 @@ void Uic::registerDatabases( const TQDomElement& e )
\sa registeredName(), isObjectRegistered()
*/
-TQString Uic::registerObject( const TQString& name )
+TQString TQUic::registerObject( const TQString& name )
{
if ( objectNames.isEmpty() ) {
// some temporary variables we need
@@ -1074,7 +1074,7 @@ TQString Uic::registerObject( const TQString& name )
\sa registerObject(), isObjectRegistered()
*/
-TQString Uic::registeredName( const TQString& name )
+TQString TQUic::registeredName( const TQString& name )
{
if ( !objectMapper.contains( name ) )
return name;
@@ -1084,7 +1084,7 @@ TQString Uic::registeredName( const TQString& name )
/*!
Returns whether the object \a name was registered yet or not.
*/
-bool Uic::isObjectRegistered( const TQString& name )
+bool TQUic::isObjectRegistered( const TQString& name )
{
return objectMapper.contains( name );
}
@@ -1093,7 +1093,7 @@ bool Uic::isObjectRegistered( const TQString& name )
/*!
Unifies the entries in stringlist \a list. Should really be a TQStringList feature.
*/
-TQStringList Uic::unique( const TQStringList& list )
+TQStringList TQUic::unique( const TQStringList& list )
{
if ( list.isEmpty() )
return list;
@@ -1111,7 +1111,7 @@ TQStringList Uic::unique( const TQStringList& list )
/*!
Creates an instance of class \a objClass, with parent \a parent and name \a objName
*/
-TQString Uic::createObjectInstance( const TQString& objClass, const TQString& parent, const TQString& objName )
+TQString TQUic::createObjectInstance( const TQString& objClass, const TQString& parent, const TQString& objName )
{
if (( objClass.mid( 1 ) == "ComboBox" ) || ( objClass.mid( 2 ) == "ComboBox" )) {
@@ -1120,7 +1120,7 @@ TQString Uic::createObjectInstance( const TQString& objClass, const TQString& pa
return objClass + "( " + parent + ", \"" + objName + "\" )";
}
-bool Uic::isLayout( const TQString& name ) const
+bool TQUic::isLayout( const TQString& name ) const
{
return layoutObjects.contains( name );
}
diff --git a/tools/designer/uic/uic.h b/tools/designer/tquic/tquic.h
index b09d6703..a296e4f5 100644
--- a/tools/designer/uic/uic.h
+++ b/tools/designer/tquic/tquic.h
@@ -41,10 +41,10 @@
#include <tqpalette.h>
#include <tqvariant.h>
-class Uic : public TQt
+class TQUic : public TQt
{
public:
- Uic( const TQString &fn, const char *outputFn, TQTextStream& out,
+ TQUic( const TQString &fn, const char *outputFn, TQTextStream& out,
TQDomDocument doc, bool decl, bool subcl, const TQString &trm,
const TQString& subclname, bool omitForwardDecls );
diff --git a/tools/designer/uic/uic.pro b/tools/designer/tquic/tquic.pro
index 722dedfb..40a9b436 100644
--- a/tools/designer/uic/uic.pro
+++ b/tools/designer/tquic/tquic.pro
@@ -1,6 +1,6 @@
TEMPLATE = app
CONFIG += qt console warn_on release professional
-HEADERS = uic.h \
+HEADERS = tquic.h \
../shared/widgetdatabase.h \
../shared/domtool.h \
../shared/parser.h \
@@ -9,7 +9,7 @@ HEADERS = uic.h \
#HEADERS += ../shared/ui2uib.h \
# ../shared/uib.h
-SOURCES = main.cpp uic.cpp form.cpp object.cpp \
+SOURCES = main.cpp tquic.cpp form.cpp object.cpp \
subclassing.cpp embed.cpp\
../shared/widgetdatabase.cpp \
../shared/domtool.cpp \
@@ -23,7 +23,7 @@ include( ../../../src/qt_professional.pri )
TARGET = tquic
INCLUDEPATH += ../shared
-DEFINES += UIC
+DEFINES += TQUIC
DESTDIR = ../../../bin
target.path=$$bins.path
diff --git a/tools/designer/uic/form.cpp b/tools/designer/tquic/form.cpp
index a3ec6801..09b3a682 100644
--- a/tools/designer/uic/form.cpp
+++ b/tools/designer/tquic/form.cpp
@@ -31,7 +31,7 @@
**
**********************************************************************/
-#include "uic.h"
+#include "tquic.h"
#include "parser.h"
#include "widgetdatabase.h"
#include "domtool.h"
@@ -123,7 +123,7 @@ TQCString combinePath( const char *infile, const char *outfile )
\sa createFormImpl(), createObjectDecl()
*/
-void Uic::createFormDecl( const TQDomElement &e )
+void TQUic::createFormDecl( const TQDomElement &e )
{
TQDomElement n;
TQDomNodeList nl;
@@ -296,7 +296,7 @@ void Uic::createFormDecl( const TQDomElement &e )
forwardDecl += s;
if ( (s.mid( 2 ) == "ListBox") || (s.mid( 2 ) == "ListView") || (s.mid( 2 ) == "IconView") )
forwardDecl += "TQ" + s.mid( 2 ) + "Item";
- if ( s == "TQDataTable" ) { // other convenience classes which are used in TQDataTable signals, and thus should be forward-declared by uic for us
+ if ( s == "TQDataTable" ) { // other convenience classes which are used in TQDataTable signals, and thus should be forward-declared by tquic for us
forwardDecl += "TQSqlRecord";
}
}
@@ -624,7 +624,7 @@ void Uic::createFormDecl( const TQDomElement &e )
out << "#endif // " << protector << endl;
}
-void Uic::writeFunctionsDecl( const TQStringList &fuLst, const TQStringList &typLst, const TQStringList &specLst )
+void TQUic::writeFunctionsDecl( const TQStringList &fuLst, const TQStringList &typLst, const TQStringList &specLst )
{
TQValueListConstIterator<TQString> it, it2, it3;
for ( it = fuLst.begin(), it2 = typLst.begin(), it3 = specLst.begin();
@@ -656,7 +656,7 @@ void Uic::writeFunctionsDecl( const TQStringList &fuLst, const TQStringList &typ
\sa createFormDecl(), createObjectImpl()
*/
-void Uic::createFormImpl( const TQDomElement &e )
+void TQUic::createFormImpl( const TQDomElement &e )
{
TQDomElement n;
TQDomNodeList nl;
@@ -897,7 +897,7 @@ void Uic::createFormImpl( const TQDomElement &e )
TQByteArray baunzip = unzipXPM( data, length );
length = baunzip.size();
// shouldn't we test the initial 'length' against the
// resulting 'length' to catch corrupt UIC files?
int a = 0;
int column = 0;
bool inQuote = FALSE;
@@ -1435,7 +1435,7 @@ void Uic::createFormImpl( const TQDomElement &e )
Traverses recursively over all children.
*/
-void Uic::createFormImpl( const TQDomElement& e, const TQString& form, const TQString& connection, const TQString& table )
+void TQUic::createFormImpl( const TQDomElement& e, const TQString& form, const TQString& connection, const TQString& table )
{
if ( e.tagName() == "widget" &&
e.attribute( "class" ) != "TQDataTable" ) {
@@ -897,7 +897,7 @@ void Uic::createFormImpl( const TQDomElement &e )
length = baunzip.size();
// shouldn't we test the initial 'length' against the
- // resulting 'length' to catch corrupt UIC files?
+ // resulting 'length' to catch corrupt TQUIC files?
int a = 0;
int column = 0;